searchData={"items":[{"type":"module","title":"PhoenixAssetPipeline","doc":"Phoenix asset pipeline application","ref":"PhoenixAssetPipeline.html"},{"type":"function","title":"PhoenixAssetPipeline.env/0","doc":"","ref":"PhoenixAssetPipeline.html#env/0"},{"type":"module","title":"PhoenixAssetPipeline.Parser.JSON","doc":"JSON parser, based on Erlang/OTP 27.0","ref":"PhoenixAssetPipeline.Parser.JSON.html"},{"type":"function","title":"PhoenixAssetPipeline.Parser.JSON.decode!/1","doc":"","ref":"PhoenixAssetPipeline.Parser.JSON.html#decode!/1"},{"type":"function","title":"PhoenixAssetPipeline.Parser.JSON.encode_to_iodata!/1","doc":"","ref":"PhoenixAssetPipeline.Parser.JSON.html#encode_to_iodata!/1"},{"type":"module","title":"PhoenixAssetPipeline.Plug.Static","doc":"A plug for serving static assets.\n\nIt requires two options:\n\n  * `:at` - the request path to reach for static assets.\n    It must be a string.\n\n  * `:from` - the file system path to read static assets from.\n    It can be either: a string containing a file system path, an\n    atom representing the application name (where assets will\n    be served from `priv/static`), a tuple containing the\n    application name and the directory to serve assets from (besides\n    `priv/static`), or an MFA tuple.\n\nThe preferred form is to use `:from` with an atom or tuple, since\nit will make your application independent from the starting directory.\nFor example, if you pass:\n\n    plug Plug.Static, from: \"priv/app/path\"\n\nPlug.Static will be unable to serve assets if you build releases\nor if you change the current directory. Instead do:\n\n    plug Plug.Static, from: {:app_name, \"priv/app/path\"}\n\nIf a static asset cannot be found, `Plug.Static` simply forwards\nthe connection to the rest of the pipeline.","ref":"PhoenixAssetPipeline.Plug.Static.html"},{"type":"module","title":"Cache mechanisms - PhoenixAssetPipeline.Plug.Static","doc":"`Plug.Static` uses etags for HTTP caching. This means browsers/clients\nshould cache assets on the first request and validate the cache on\nfollowing requests, not downloading the static asset once again if it\nhas not changed. The cache-control for etags is specified by the\n`cache_control_for_etags` option and defaults to `\"public\"`.\n\nHowever, `Plug.Static` also supports direct cache control by using\nversioned query strings. If the request query string starts with\n\"?vsn=\", `Plug.Static` assumes the application is versioning assets\nand does not set the `ETag` header, meaning the cache behaviour will\nbe specified solely by the `cache_control_for_vsn_requests` config,\nwhich defaults to `\"public, max-age=31536000\"`.","ref":"PhoenixAssetPipeline.Plug.Static.html#module-cache-mechanisms"},{"type":"module","title":"Options - PhoenixAssetPipeline.Plug.Static","doc":"* `:encodings` - list of 2-ary tuples where first value is value of\n    the `Accept-Encoding` header and second is extension of the file to\n    be served if given encoding is accepted by client. Entries will be tested\n    in order in list, so entries higher in list will be preferred. Defaults\n    to: `[]`.\n\n    In addition to setting this value directly it supports 2 additional\n    options for compatibility reasons:\n\n      + `:brotli` - will append `{\"br\", \".br\"}` to the encodings list.\n      + `:gzip` - will append `{\"gzip\", \".gz\"}` to the encodings list.\n\n    Additional options will be added in the above order (Brotli takes\n    preference over Gzip) to reflect older behaviour which was set due\n    to fact that Brotli in general provides better compression ratio than\n    Gzip.\n\n  * `:cache_control_for_etags` - sets the cache header for requests\n    that use etags. Defaults to `\"public\"`.\n\n  * `:etag_generation` - specify a `{module, function, args}` to be used\n    to generate   an etag. The `path` of the resource will be passed to\n    the function, as well as the `args`. If this option is not supplied,\n    etags will be generated based off of file size and modification time.\n    Note it is [recommended for the etag value to be quoted](https://tools.ietf.org/html/rfc7232#section-2.3),\n    which Plug won't do automatically.\n\n  * `:cache_control_for_vsn_requests` - sets the cache header for\n    requests starting with \"?vsn=\" in the query string. Defaults to\n    `\"public, max-age=31536000\"`.\n\n  * `:only` - filters which requests to serve. This is useful to avoid\n    file system access on every request when this plug is mounted\n    at `\"/\"`. For example, if `only: [\"images\", \"favicon.ico\"]` is\n    specified, only files in the \"images\" directory and the\n    \"favicon.ico\" file will be served by `Plug.Static`.\n    Note that `Plug.Static` matches these filters against request\n    uri and not against the filesystem. When requesting\n    a file with name containing non-ascii or special characters,\n    you should use urlencoded form. For example, you should write\n    `only: [\"file%20name\"]` instead of `only: [\"file name\"]`.\n    Defaults to `nil` (no filtering).\n\n  * `:only_matching` - a relaxed version of `:only` that will\n    serve any request as long as one of the given values matches the\n    given path. For example, `only_matching: [\"images\", \"favicon\"]`\n    will match any request that starts at \"images\" or \"favicon\",\n    be it \"/images/foo.png\", \"/images-high/foo.png\", \"/favicon.ico\"\n    or \"/favicon-high.ico\". Such matches are useful when serving\n    digested files at the root. Defaults to `nil` (no filtering).\n\n  * `:headers` - other headers to be set when serving static assets. Specify either\n    an enum of key-value pairs or a `{module, function, args}` to return an enum. The\n    `conn` will be passed to the function, as well as the `args`.\n\n  * `:content_types` - controls custom MIME type mapping.\n    It can be a map with filename as key and content type as value to override\n    the default type for matching filenames. For example:\n    `content_types: %{\"apple-app-site-association\" => \"application/json\"}`.\n    Alternatively, it can be the value `false` to opt out of setting the header at all. The latter\n    can be used to set the header based on custom logic before calling this plug.\n    Defaults to an empty map `%{}`.","ref":"PhoenixAssetPipeline.Plug.Static.html#module-options"},{"type":"module","title":"Examples - PhoenixAssetPipeline.Plug.Static","doc":"This plug can be mounted in a `Plug.Builder` pipeline as follows:\n\n    defmodule MyPlug do\n      use Plug.Builder\n\n      plug Plug.Static,\n        at: \"/public\",\n        from: :my_app,\n        only: ~w(images robots.txt)\n      plug :not_found\n\n      def not_found(conn, _) do\n        send_resp(conn, 404, \"not found\")\n      end\n    end","ref":"PhoenixAssetPipeline.Plug.Static.html#module-examples"},{"type":"exception","title":"PhoenixAssetPipeline.Plug.Static.InvalidPathError","doc":"","ref":"PhoenixAssetPipeline.Plug.Static.InvalidPathError.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}